Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckConfigExistOrCreateNew ¶ added in v0.0.5
func GenerateAESKey ¶
GenerateAESKey generates a random AES key of the specified size (16, 24, or 32 bytes)
Types ¶
type Config ¶
func ParseConfig ¶
ParseConfig reads the config file, fills config fields, and validates them.
type Folder ¶
func (*Folder) SecureString ¶
type Storage ¶
type Storage struct {
PrivKey []byte
Data string
Cfg *Config
// contains filtered or unexported fields
}
Storage struct to hold the data read from the file
Click to show internal directories.
Click to hide internal directories.